==> open-cluster-management-operator-model-5.12.4-sources.jar: io/fabric8/openclustermanagement/api/model/multiclusterhub/operator/v1/MultiClusterHubSpecBuilder.java <==
package io.fabric8.openclustermanagement.api.model.multiclusterhub.operator.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class MultiClusterHubSpecBuilder extends io.fabric8.openclustermanagement.api.model.multiclusterhub.operator.v1.MultiClusterHubSpecFluentImpl<io.fabric8.openclustermanagement.api.model.multiclusterhub.operator.v1.MultiClusterHubSpecBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openclustermanagement.api.model.multiclusterhub.operator.v1.MultiClusterHubSpec,io.fabric8.openclustermanagement.api.model.multiclusterhub.operator.v1.MultiClusterHubSpecBuilder>{
  public MultiClusterHubSpecBuilder() {
    this(false);
  }
  public MultiClusterHubSpecBuilder(java.lang.Boolean validationEnabled) {
    this(new MultiClusterHubSpec(), validationEnabled);
  }
  public MultiClusterHubSpecBuilder(io.fabric8.openclustermanagement.api.model.multiclusterhub.operator.v1.MultiClusterHubSpecFluent<?> fluent) {
    this(fluent, false);
  }
  public MultiClusterHubSpecBuilder(io.fabric8.openclustermanagement.api.model.multiclusterhub.operator.v1.MultiClusterHubSpecFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new MultiClusterHubSpec(), validationEnabled);
  }
  public MultiClusterHubSpecBuilder(io.fabric8.openclustermanagement.api.model.multiclusterhub.operator.v1.MultiClusterHubSpecFluent<?> fluent,io.fabric8.openclustermanagement.api.model.multiclusterhub.operator.v1.MultiClusterHubSpec instance) {
    this(fluent, instance, false);
  }
  public MultiClusterHubSpecBuilder(io.fabric8.openclustermanagement.api.model.multiclusterhub.operator.v1.MultiClusterHubSpecFluent<?> fluent,io.fabric8.openclustermanagement.api.model.multiclusterhub.operator.v1.MultiClusterHubSpec instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withAvailabilityConfig(instance.getAvailabilityConfig()); 
    fluent.withCustomCAConfigmap(instance.getCustomCAConfigmap()); 
    fluent.withDisableHubSelfManagement(instance.getDisableHubSelfManagement()); 
    fluent.withDisableUpdateClusterImageSets(instance.getDisableUpdateClusterImageSets()); 
    fluent.withEnableClusterBackup(instance.getEnableClusterBackup()); 
    fluent.withEnableClusterProxyAddon(instance.getEnableClusterProxyAddon()); 
    fluent.withHive(instance.getHive()); 
    fluent.withImagePullSecret(instance.getImagePullSecret()); 
    fluent.withIngress(instance.getIngress()); 
    fluent.withNodeSelector(instance.getNodeSelector()); 
    fluent.withOverrides(instance.getOverrides()); 
    fluent.withSeparateCertificateManagement(instance.getSeparateCertificateManagement()); 
    this.validationEnabled = validationEnabled; 
  }
  public MultiClusterHubSpecBuilder(io.fabric8.openclustermanagement.api.model.multiclusterhub.operator.v1.MultiClusterHubSpec instance) {
    this(instance,false);
  }
  public MultiClusterHubSpecBuilder(io.fabric8.openclustermanagement.api.model.multiclusterhub.operator.v1.MultiClusterHubSpec instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withAvailabilityConfig(instance.getAvailabilityConfig()); 
    this.withCustomCAConfigmap(instance.getCustomCAConfigmap()); 
    this.withDisableHubSelfManagement(instance.getDisableHubSelfManagement()); 
    this.withDisableUpdateClusterImageSets(instance.getDisableUpdateClusterImageSets()); 
    this.withEnableClusterBackup(instance.getEnableClusterBackup()); 
    this.withEnableClusterProxyAddon(instance.getEnableClusterProxyAddon()); 
    this.withHive(instance.getHive()); 
    this.withImagePullSecret(instance.getImagePullSecret()); 
    this.withIngress(instance.getIngress()); 
    this.withNodeSelector(instance.getNodeSelector()); 
    this.withOverrides(instance.getOverrides()); 
    this.withSeparateCertificateManagement(instance.getSeparateCertificateManagement()); 
    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openclustermanagement.api.model.multiclusterhub.operator.v1.MultiClusterHubSpecFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openclustermanagement.api.model.multiclusterhub.operator.v1.MultiClusterHubSpec build() {
    MultiClusterHubSpec buildable = new MultiClusterHubSpec(fluent.getAvailabilityConfig(),fluent.getCustomCAConfigmap(),fluent.getDisableHubSelfManagement(),fluent.getDisableUpdateClusterImageSets(),fluent.getEnableClusterBackup(),fluent.getEnableClusterProxyAddon(),fluent.getHive(),fluent.getImagePullSecret(),fluent.getIngress(),fluent.getNodeSelector(),fluent.getOverrides(),fluent.getSeparateCertificateManagement());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    MultiClusterHubSpecBuilder that = (MultiClusterHubSpecBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> open-cluster-management-operator-model-6.3.0-sources.jar: io/fabric8/openclustermanagement/api/model/multiclusterhub/operator/v1/MultiClusterHubSpecBuilder.java <==
package io.fabric8.openclustermanagement.api.model.multiclusterhub.operator.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class MultiClusterHubSpecBuilder extends MultiClusterHubSpecFluentImpl<MultiClusterHubSpecBuilder> implements VisitableBuilder<MultiClusterHubSpec,MultiClusterHubSpecBuilder>{
  public MultiClusterHubSpecBuilder() {
    this(false);
  }
  public MultiClusterHubSpecBuilder(Boolean validationEnabled) {
    this(new MultiClusterHubSpec(), validationEnabled);
  }
  public MultiClusterHubSpecBuilder(MultiClusterHubSpecFluent<?> fluent) {
    this(fluent, false);
  }
  public MultiClusterHubSpecBuilder(MultiClusterHubSpecFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new MultiClusterHubSpec(), validationEnabled);
  }
  public MultiClusterHubSpecBuilder(MultiClusterHubSpecFluent<?> fluent,MultiClusterHubSpec instance) {
    this(fluent, instance, false);
  }
  public MultiClusterHubSpecBuilder(MultiClusterHubSpecFluent<?> fluent,MultiClusterHubSpec instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withAvailabilityConfig(instance.getAvailabilityConfig()); 
    fluent.withCustomCAConfigmap(instance.getCustomCAConfigmap()); 
    fluent.withDisableHubSelfManagement(instance.getDisableHubSelfManagement()); 
    fluent.withDisableUpdateClusterImageSets(instance.getDisableUpdateClusterImageSets()); 
    fluent.withEnableClusterBackup(instance.getEnableClusterBackup()); 
    fluent.withEnableClusterProxyAddon(instance.getEnableClusterProxyAddon()); 
    fluent.withHive(instance.getHive()); 
    fluent.withImagePullSecret(instance.getImagePullSecret()); 
    fluent.withIngress(instance.getIngress()); 
    fluent.withNodeSelector(instance.getNodeSelector()); 
    fluent.withOverrides(instance.getOverrides()); 
    fluent.withSeparateCertificateManagement(instance.getSeparateCertificateManagement()); 
    this.validationEnabled = validationEnabled; 
  }
  public MultiClusterHubSpecBuilder(MultiClusterHubSpec instance) {
    this(instance,false);
  }
  public MultiClusterHubSpecBuilder(MultiClusterHubSpec instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withAvailabilityConfig(instance.getAvailabilityConfig()); 
    this.withCustomCAConfigmap(instance.getCustomCAConfigmap()); 
    this.withDisableHubSelfManagement(instance.getDisableHubSelfManagement()); 
    this.withDisableUpdateClusterImageSets(instance.getDisableUpdateClusterImageSets()); 
    this.withEnableClusterBackup(instance.getEnableClusterBackup()); 
    this.withEnableClusterProxyAddon(instance.getEnableClusterProxyAddon()); 
    this.withHive(instance.getHive()); 
    this.withImagePullSecret(instance.getImagePullSecret()); 
    this.withIngress(instance.getIngress()); 
    this.withNodeSelector(instance.getNodeSelector()); 
    this.withOverrides(instance.getOverrides()); 
    this.withSeparateCertificateManagement(instance.getSeparateCertificateManagement()); 
    this.validationEnabled = validationEnabled; 
  }
  MultiClusterHubSpecFluent<?> fluent;
  Boolean validationEnabled;
  public MultiClusterHubSpec build() {
    MultiClusterHubSpec buildable = new MultiClusterHubSpec(fluent.getAvailabilityConfig(),fluent.getCustomCAConfigmap(),fluent.getDisableHubSelfManagement(),fluent.getDisableUpdateClusterImageSets(),fluent.getEnableClusterBackup(),fluent.getEnableClusterProxyAddon(),fluent.getHive(),fluent.getImagePullSecret(),fluent.getIngress(),fluent.getNodeSelector(),fluent.getOverrides(),fluent.getSeparateCertificateManagement());
    return buildable;
  }
  
}
